/*
 * Configured Wi-Fi list
 *  for Wi-Fi view & select
 */
package jp.gr.java_conf.j_sota.wifiviewandselect;

import java.util.ArrayList;

import android.os.Bundle;
import android.os.Parcel;
import android.os.Parcelable;

// Implement Parcelable since this class is transferred with Bundle
public class ConfiguredWifiList implements Parcelable {
	
	private ArrayList<ConfiguredWifiListData> mWifiList;

	/**
	 * Return a array body
	 * @return		Configured Wi-Fi list
	 */
	public ArrayList<ConfiguredWifiListData> getArray() {
		return mWifiList;
	}

	/**
	 * Add configured Wi-Fi data to list
	 * @param ssid				SSID
	 * @param signalLevel		Signal level
	 * @param networkId			Network ID
	 */
	public void add(String ssid, int signalLevel, int networkId) {
		ConfiguredWifiListData data = new ConfiguredWifiListData();
		data.ssid = ssid;
		data.signalLevel = signalLevel;
		data.networkId = networkId;
		mWifiList.add(data);
	}

	/**
	 * Get SSID from position
	 * @param position	Position
	 * @return String	SSID
	 */
	public String getSsid(int position) {
		return mWifiList.get(position).ssid;
	}

	/**
	 * Get signal level from position
	 * @param position	Position
	 * @return int		Signal level
	 */
	public int getSignalLevel(int position) {
		return mWifiList.get(position).signalLevel;
	}

	/**
	 * Set signal level from position
	 * @param position		Position
	 * @param signalLevel	Signal level
	 */
	public void setSignalLevel(int position, int signalLevel) {
		ConfiguredWifiListData data = mWifiList.get(position);
		data.signalLevel = signalLevel;
	}

	/**
	 * Get network ID from position
	 * @param position	Position
	 * @return int 	Network ID
	 */
	public int getNetworkId(int position) {
		return mWifiList.get(position).networkId;
	}

	/**
	 * Return a list data size
	 * @return int		list data size
	 */
	public int size() {
		return mWifiList.size();
	}

	public static final Parcelable.Creator<ConfiguredWifiList> CREATOR =
		new Parcelable.Creator<ConfiguredWifiList>() {

			/**
			 * Create list from parcel
			 * @param in	parcel data
			 */
			public ConfiguredWifiList createFromParcel(Parcel in) {
				return new ConfiguredWifiList(in);
			}

			/**
			 * Create a new array
			 * @param size		size
			 * @return ConfiguredWifiList[] array
			 */
			public ConfiguredWifiList[] newArray(int size) {
				return new ConfiguredWifiList[size];
			}
		};

	/**
	 * Constructor
	 * No initial data
	 */
	public ConfiguredWifiList() {
		mWifiList = new ArrayList<ConfiguredWifiListData>();
	}

	/**
	 * Constructor
	 * read data from parcel
	 * @param in	Parcel data
	 */
	private ConfiguredWifiList(Parcel in) {
		Bundle b = in.readBundle(ConfiguredWifiListData.class.getClassLoader());
		mWifiList = b.getParcelableArrayList("items");
	}

	/**
	 * Write to Parcel
	 * @param dest
	 * @param flags
	 */
	public void writeToParcel(Parcel dest, int flags) {
		Bundle b = new Bundle();
		b.putParcelableArrayList("items", mWifiList);
		dest.writeBundle(b);
	}

	/**
	 * Describe contents
	 * @return always 0
	 */
	public int describeContents() {
		return 0;
	}
}
