/*
 * LED color setting list adapter for list view
 *  for Wi-Fi view & select
 */
package jp.gr.java_conf.j_sota.wifiviewandselect;

import java.util.List;

import android.content.Context;
import android.graphics.Bitmap;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.TextView;

public class LedColorListAdapter extends BaseAdapter {

	private List<LedColorListData> mUserData;
	private LayoutInflater mInflater;

	/**
	 * Constructor
	 * @param context	Context
	 * @param users		LED color setting list
	 */
	public LedColorListAdapter(Context context, List<LedColorListData> users) {
		mUserData = users;
		mInflater = (LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
	}

	/**
	 * Constructor
	 * @param context	Context
	 */
	public LedColorListAdapter(Context context) {
		mInflater = (LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
	}

	/**
	 * Set data
	 * @param users		LED color setting list
	 */
	public void setData(List<LedColorListData> users) {
		mUserData = users;
	}

	/**
	 * Return a count of LED color setting list
	 * @return int count
	 */
	public int getCount() {
		return mUserData.size();
	}

	/**
	 * Return a LED color setting data from position
	 * @param position
	 * @return Object 	LED color setting data
	 */
	public Object getItem(int position) {
		return mUserData.get(position);
	}

	/**
	 * Return a item ID
	 * @param position		Position
	 * @return long 		Item ID
	 */
	public long getItemId(int position) {
		return position;
	}

	/**
	 * Return a view
	 * @param position		Position
	 * @param convertView	View
	 * @param parent		Parent
	 * @return View		view
	 */
	public View getView(int position, View convertView, ViewGroup parent) {
		View view = convertView;
		if (view == null) {
			view = mInflater.inflate(R.layout.led_color_setting_row, null);
		}
		LedColorListData user = mUserData.get(position);

		// Show SSID
		TextView title = (TextView) view.findViewById(R.id.textSsid);
		title.setText(user.ssid);

		// Show LED Image
		ImageView mImageView = (ImageView) view.findViewById(R.id.imageLedColor);
		LedImage ledImage = new LedImage(view.getContext());
		Bitmap bitmap = ledImage.getLedImage(user.ledColor);
		mImageView.setImageBitmap(bitmap);

		return view;
	}
}
